=======
Credits
=======

Development Lead
----------------

* Krzysztof Machelski <krzysztof.machelski+pypi@gmail.com>

Contributors
------------

* Grzegorz Wisniewski <grzeg.wisniewski@gmail.com>
* Grzegorz Szostak <szostak.grzegorz@gmail.com>

